@@ -1,4 +1,4 @@
 from __future__ import absolute_import
+
+from . import burntiles, uniontiles
 from . import edge_finder as edgetiles
-from . import burntiles
-from . import uniontiles
